#!/bin/sh
echo 'name: heist
version: 0.7.0.1
id: heist-0.7.0.1-6b6dc23345389b0d6415f5b21dd341db

license: BSD3
copyright:
maintainer: snap@snapframework.com
stability:
homepage: http://snapframework.com/
package-url:
description: An (x)html templating system
category: Web, Snap
author: Doug Beardsley, Gregory Collins
pkgpath: textproc/hs-heist
exposed: True
exposed-modules: Text.Templating.Heist
                 Text.Templating.Heist.Splices Text.Templating.Heist.Splices.Apply
                 Text.Templating.Heist.Splices.Bind
                 Text.Templating.Heist.Splices.BindStrict
                 Text.Templating.Heist.Splices.Cache
                 Text.Templating.Heist.Splices.Html
                 Text.Templating.Heist.Splices.Ignore
                 Text.Templating.Heist.Splices.Markdown
                 Text.Templating.Heist.Splices.Static
                 Text.Templating.Heist.TemplateDirectory
hidden-modules: Text.Templating.Heist.Internal
                Text.Templating.Heist.Types
import-dirs: /usr/local/lib/ghc/heist-0.7.0.1
library-dirs: /usr/local/lib/ghc/heist-0.7.0.1
hs-libraries: HSheist-0.7.0.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: MonadCatchIO-transformers-0.2.2.0-21f55e3743ac58803f508355a9eecc56
         attoparsec-0.10.1.0-fbbd15f07775c506a88ff9688f1e3d80
         base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
         blaze-builder-0.2.1.4-bfcede572046050679f95fe80b55244e
         bytestring-0.9.1.10-4e62762ee9b2a5d0cc5bc2fbaaeefd53
         containers-0.4.0.0-f1307d32d8f4b51a1487c01f0997b6d9
         directory-1.1.0.0-ca04ddcf1c341deb4150c220bedd97c0
         directory-tree-0.10.0-3ab150c00cb9297ad1155138f8040162
         filepath-1.2.0.0-956a4b0c127b8c317f6cac3946b0b803
         mtl-2.0.1.0-3e464329054b7660133198d73c31aca5
         process-1.0.1.5-99e45a86cf1678266024ae9c30d1f778
         random-1.0.0.3-186815de972cb506efde02a72b0d8f8b
         text-0.11.1.5-a9f0a532672121c1439a824b6891e297
         time-1.2.0.3-ad46a3ade48e0011608895f44cc02a52
         transformers-0.2.2.0-89265f646be3aed4f502cfc5eccd7c93
         xmlhtml-0.1.5.2-7ba59cbbd2629d88dee3e7a20705bcb5
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-heist-0.7.0.1/html/heist.haddock
haddock-html: /usr/local/share/doc/hs-heist-0.7.0.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
